set daemon <poll interval>

set logfile <plesk dir>/var/modules/watchdog/log/monit.log
set pidfile <monit.pid>
set statefile <plesk dir>/var/modules/watchdog/run/monit.state

set httpd port <monit TCP port> and use address localhost
	allow localhost
	allow <monit login>:<monit password> read-only

set mailserver <mail servers>
set mailserver <mail servers> with timeout <mail servers timeout> seconds

set mail-format {
	from: monitoring-service@<host>
}

set alert <event::nonwork::to> {nonexist, connection} mail-format {
	from: <event::nonwork::from>
	subject: [<event::nonwork::subj>]
	message: [<event::nonwork::mess>]
}

set alert <event::exec::to> {exec} mail-format {
	from: <event::exec::from>
	subject: [<event::exec::subj>]
	message: [<event::exec::mess>]
}

set alert <event::timeout::to> {timeout} mail-format {
	from: <event::timeout::from>
	subject: [<event::timeout::subj>]
	message: [<event::timeout::mess>]
}

# Plesk apache
check process plesk_apache
	with pidfile "<plesk dir>/admin/logs/httpsd.pid"
	start = "<plesk_apache::start>"
	stop = "<plesk_apache::stop>"
	if failed port 8443 type tcpssl protocol http with timeout <plesk_apache::connection_timeout> seconds then <plesk_apache::action>
	[<rem plesk_apache::timeout>]if <plesk_apache::timeout::restarts> restarts within <plesk_apache::timeout::cycles> cycles then timeout
	every <plesk_apache::every cycles> cycles
	[<rem plesk_apache::alert::nonwork>]alert <plesk_apache::alert::nonwork::to> { nonexist, connection } [<plesk_apache::alert::nonwork::mail-format>]
	[<rem plesk_apache::alert::exec>]alert <plesk_apache::alert::exec::to> { exec } [<plesk_apache::alert::exec::mail-format>]
	[<rem plesk_apache::alert::timeout>]alert <plesk_apache::alert::timeout::to> { timeout } [<plesk_apache::alert::timeout::mail-format>]
	alert <default email to> {invalid}
	mode <plesk_apache::mode>

# Apache
check process apache
	with pidfile "/var/run/httpd2.pid"
	start = "<apache::start>"
	stop = "<apache::stop>"
	if failed port 80 protocol http with timeout <apache::connection_timeout> seconds then <apache::action>
	[<rem apache::timeout>]if <apache::timeout::restarts> restarts within <apache::timeout::cycles> cycles then timeout
	every <apache::every cycles> cycles
	[<rem apache::alert::nonwork>]alert <apache::alert::nonwork::to> { nonexist, connection } [<apache::alert::nonwork::mail-format>]
	[<rem apache::alert::exec>]alert <apache::alert::exec::to> { exec } [<apache::alert::exec::mail-format>]
	[<rem apache::alert::timeout>]alert <apache::alert::timeout::to> { timeout } [<apache::alert::timeout::mail-format>]
	alert <default email to> {invalid}
	mode <apache::mode>

# Qmail
check process qmail
        with pidfile "/var/run/qmail.pid"
        start = "<qmail::start>"
        stop = "<qmail::stop>"
        [<rem qmail::timeout>]if <qmail::timeout::restarts> restarts within <qmail::timeout::cycles> cycles then timeout
        every <qmail::every cycles> cycles
        [<rem qmail::alert::exec>]alert <qmail::alert::exec::to> { exec }
        [<qmail::alert::exec::mail-format>]
        [<rem qmail::alert::timeout>]alert <qmail::alert::timeout::to> { timeout } [<qmail::alert::timeout::mail-format>]
        alert <default email to> {invalid}
        mode <qmail::mode>

# Qmail-smtpd
check host qmail_smtpd with address localhost
        if failed host localhost port 25 protocol smtp with timeout <qmail::connection_timeout> seconds then alert
        [<rem qmail::timeout>]if <qmail::timeout::restarts> restarts within <qmail::timeout::cycles> cycles then timeout
        every <qmail::every cycles> cycles
        [<rem qmail::alert::nonwork>]alert <qmail::alert::nonwork::to> { connection } [<qmail::alert::nonwork::mail-format>]
        [<rem qmail::alert::timeout>]alert <qmail::alert::timeout::to> { timeout } [<qmail::alert::timeout::mail-format>]
        alert <default email to> {invalid}
        mode <qmail::mode>

# Courier-IMAP
check process courier-imap with pidfile "/var/run/imapd.pid"
	start = "<courier-imap::start>"
	stop = "<courier-imap::stop>"
	if failed port 143 protocol imap with timeout <courier-imap::connection_timeout> seconds then <courier-imap::action>
	if failed port 993 type tcpssl protocol imap with timeout <courier-imap::connection_timeout> seconds then <courier-imap::action>
	if failed port 110 protocol pop with timeout <courier-imap::connection_timeout> seconds then <courier-imap::action>
	if failed port 995 type tcpssl protocol pop with timeout <courier-imap::connection_timeout> seconds then <courier-imap::action>
	[<rem courier-imap::timeout>]if <courier-imap::timeout::restarts> restarts within <courier-imap::timeout::cycles> cycles then timeout
	every <courier-imap::every cycles> cycles
	[<rem courier-imap::alert::nonwork>]alert <courier-imap::alert::nonwork::to> { nonexist, connection } [<courier-imap::alert::nonwork::mail-format>]
	[<rem courier-imap::alert::exec>]alert <courier-imap::alert::exec::to> { exec } [<courier-imap::alert::exec::mail-format>]
	[<rem courier-imap::alert::timeout>]alert <courier-imap::alert::timeout::to> { timeout } [<courier-imap::alert::timeout::mail-format>]
	alert <default email to> {invalid}
	mode <courier-imap::mode>

# Bind
check process bind
	with pidfile "/var/run/named/named.pid"
	start = "<bind::start>"
	stop = "<bind::stop>"
    if failed port 53 type tcp with timeout <bind::connection_timeout> seconds then <bind::action>
    if failed port 53 type udp with timeout <bind::connection_timeout> seconds then <bind::action>
	[<rem bind::timeout>]if <bind::timeout::restarts> restarts within <bind::timeout::cycles> cycles then timeout
	every <bind::every cycles> cycles
	[<rem bind::alert::nonwork>]alert <bind::alert::nonwork::to> { nonexist, connection } [<bind::alert::nonwork::mail-format>]
	[<rem bind::alert::exec>]alert <bind::alert::exec::to> { exec } [<bind::alert::exec::mail-format>]
	[<rem bind::alert::timeout>]alert <bind::alert::timeout::to> { timeout } [<bind::alert::timeout::mail-format>]
	alert <default email to> {invalid}
	mode <bind::mode>

# Tomcat
check process tomcat with pidfile "/var/run/tomcat4.pid"
	start = "<tomcat::start>"
	stop = "<tomcat::stop>"
	if failed port 8080 with timeout <tomcat::connection_timeout> seconds then <tomcat::action>
	[<rem tomcat::timeout>]if <tomcat::timeout::restarts> restarts within <tomcat::timeout::cycles> cycles then timeout
	every <tomcat::every cycles> cycles
	[<rem tomcat::alert::nonwork>]alert <tomcat::alert::nonwork::to> { nonexist, connection } [<tomcat::alert::nonwork::mail-format>]
	[<rem tomcat::alert::exec>]alert <tomcat::alert::exec::to> { exec } [<tomcat::alert::exec::mail-format>]
	[<rem tomcat::alert::timeout>]alert <tomcat::alert::timeout::to> { timeout } [<tomcat::alert::timeout::mail-format>]
	alert <default email to> {invalid}
	mode <tomcat::mode>

# ColdFusion
check host coldfusion with address localhost
	start = "<coldfusion::start>"
	stop = "<coldfusion::stop>"
	if failed port 51010 protocol http with timeout <coldfusion::connection_timeout> seconds then <coldfusion::action>
	[<rem coldfusion::timeout>]if <coldfusion::timeout::restarts> restarts within <coldfusion::timeout::cycles> cycles then timeout
	every <coldfusion::every cycles> cycles
	[<rem coldfusion::alert::nonwork>]alert <coldfusion::alert::nonwork::to> { nonexist, connection } [<coldfusion::alert::nonwork::mail-format>]
	[<rem coldfusion::alert::exec>]alert <coldfusion::alert::exec::to> { exec } [<coldfusion::alert::exec::mail-format>]
	[<rem coldfusion::alert::timeout>]alert <coldfusion::alert::timeout::to> { timeout } [<coldfusion::alert::timeout::mail-format>]
	alert <default email to> {invalid}
	mode <coldfusion::mode>

# MySQL
check process mysql
	with pidfile "/var/lib/mysql/mysqld.pid"
	start = "<mysql::start>"
	stop = "<mysql::stop>"
	if failed unixsocket /var/lib/mysql/mysql.sock with timeout <mysql::connection_timeout> seconds then <mysql::action>
	[<rem mysql::timeout>]if <mysql::timeout::restarts> restarts within <mysql::timeout::cycles> cycles then timeout
	every <mysql::every cycles> cycles
	[<rem mysql::alert::nonwork>]alert <mysql::alert::nonwork::to> { nonexist, connection } [<mysql::alert::nonwork::mail-format>]
	[<rem mysql::alert::exec>]alert <mysql::alert::exec::to> { exec } [<mysql::alert::exec::mail-format>]
	[<rem mysql::alert::timeout>]alert <mysql::alert::timeout::to> { timeout } [<mysql::alert::timeout::mail-format>]
	alert <default email to> {invalid}
	mode <mysql::mode>

# PostgreSQL
check process postgresql
	with pidfile "/var/lib/pgsql/data/postmaster.pid"
	start = "<postgresql::start>"
	stop = "<postgresql::stop>"
	if failed unixsocket /tmp/.s.PGSQL.5432 with timeout <postgresql::connection_timeout> seconds then <postgresql::action>
	[<rem postgresql::timeout>]if <postgresql::timeout::restarts> restarts within <postgresql::timeout::cycles> cycles then timeout
	every <postgresql::every cycles> cycles
	[<rem postgresql::alert::nonwork>]alert <postgresql::alert::nonwork::to> { nonexist, connection } [<postgresql::alert::nonwork::mail-format>]
	[<rem postgresql::alert::exec>]alert <postgresql::alert::exec::to> { exec } [<postgresql::alert::exec::mail-format>]
	[<rem postgresql::alert::timeout>]alert <postgresql::alert::timeout::to> { timeout } [<postgresql::alert::timeout::mail-format>]
	alert <default email to> {invalid}
	mode <postgresql::mode>

# SpamAssassin
check process psa-spamassassin-full
	with pidfile "/var/run/spamd/spamd_full.pid"
	start = "<psa-spamassassin::start>"
	stop = "<psa-spamassassin::stop>"
	if failed unixsocket /tmp/spamd_full.sock with timeout <psa-spamassassin::connection_timeout> seconds then <psa-spamassassin::action>
	[<rem psa-spamassassin::timeout>]if <psa-spamassassin::timeout::restarts> restarts within <psa-spamassassin::timeout::cycles> cycles then timeout
	every <psa-spamassassin::every cycles> cycles
	[<rem psa-spamassassin::alert::nonwork>]alert <psa-spamassassin::alert::nonwork::to> { nonexist, connection } [<psa-spamassassin::alert::nonwork::mail-format>]
	[<rem psa-spamassassin::alert::exec>]alert <psa-spamassassin::alert::exec::to> { exec } [<psa-spamassassin::alert::exec::mail-format>]
	[<rem psa-spamassassin::alert::timeout>]alert <psa-spamassassin::alert::timeout::to> { timeout } [<psa-spamassassin::alert::timeout::mail-format>]
	alert <default email to> {invalid}
	mode <psa-spamassassin::mode>

check process psa-spamassassin-light
	with pidfile "/var/run/spamd/spamd_light.pid"
	start = "<psa-spamassassin::start>"
	stop = "<psa-spamassassin::stop>"
	if failed unixsocket /tmp/spamd_light.sock with timeout <psa-spamassassin::connection_timeout> seconds then <psa-spamassassin::action>
	[<rem psa-spamassassin::timeout>]if <psa-spamassassin::timeout::restarts> restarts within <psa-spamassassin::timeout::cycles> cycles then timeout
	every <psa-spamassassin::every cycles> cycles
	[<rem psa-spamassassin::alert::nonwork>]alert <psa-spamassassin::alert::nonwork::to> { nonexist, connection } [<psa-spamassassin::alert::nonwork::mail-format>]
	[<rem psa-spamassassin::alert::exec>]alert <psa-spamassassin::alert::exec::to> { exec } [<psa-spamassassin::alert::exec::mail-format>]
	[<rem psa-spamassassin::alert::timeout>]alert <psa-spamassassin::alert::timeout::to> { timeout } [<psa-spamassassin::alert::timeout::mail-format>]
	alert <default email to> {invalid}
	mode <psa-spamassassin::mode>

# Dr.Web
check process drweb
	with pidfile "/var/drweb/run/drwebd.pid"
	start = "<drweb::start>"
	stop = "<drweb::stop>"
	if failed port 3000 type tcp with timeout <drweb::connection_timeout> seconds then <drweb::action>
	[<rem drweb::timeout>]if <drweb::timeout::restarts> restarts within <drweb::timeout::cycles> cycles then timeout
	every <drweb::every cycles> cycles
	[<rem drweb::alert::nonwork>]alert <drweb::alert::nonwork::to> { nonexist, connection } [<drweb::alert::nonwork::mail-format>]
	[<rem drweb::alert::exec>]alert <drweb::alert::exec::to> { exec } [<drweb::alert::exec::mail-format>]
	[<rem drweb::alert::timeout>]alert <drweb::alert::timeout::to> { timeout } [<drweb::alert::timeout::mail-format>]
	alert <default email to> {invalid}
	mode <drweb::mode>

